.. module:: finol.optimization_layer

finol.optimization_layer
========================

The :mod:`~finol.optimization_layer` module contains optimization layer related classes and functions.

.. autosummary::
   :toctree: generated/
   :nosignatures:

    finol.optimization_layer.CriterionSelector
    finol.optimization_layer.ModelTrainer
    finol.optimization_layer.OptimizerSelector
    finol.optimization_layer.OptunaOptimizer